# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['lambdarest']

package_data = \
{'': ['*']}

install_requires = \
['jsonschema>=3.2.0,<4.0.0', 'strict_rfc3339>=0.7,<0.8', 'werkzeug==0.16.1']

setup_kwargs = {
    'name': 'lambdarest',
    'version': '12.0.0',
    'description': 'flask like web framework for AWS Lambda',
    'long_description': '![lambdarest logo](https://raw.githubusercontent.com/sloev/python-lambdarest/master/.github/lambdarest.png)\n\n# lambdarest\n\n[![Build Status](https://travis-ci.com/sloev/python-lambdarest.svg?branch=master)](https://travis-ci.com/github/sloev/python-lambdarest) [![Latest Version](https://img.shields.io/pypi/v/lambdarest.svg)](https://pypi.python.org/pypi/lambdarest) [![PyPI - Downloads](https://img.shields.io/pypi/dm/lambdarest?label=pypi%20downloads)](https://pypistats.org/packages/lambdarest) [![Python Support](https://img.shields.io/pypi/pyversions/lambdarest.svg)](https://pypi.python.org/pypi/lambdarest) [![Examples tested with pytest-readme](http://img.shields.io/badge/readme-tested-brightgreen.svg)](https://github.com/boxed/pytest-readme)\n\nPython routing mini-framework for [AWS Lambda](https://aws.amazon.com/lambda/) with optional JSON-schema validation.\n\n> ⚠️ [A **user study** is currently happening here](https://github.com/sloev/python-lambdarest/issues/76), and your opinion makes the day! Thanks for participating! 😊\n\n### Features\n\n* `lambda_handler` function constructor with built-in dispatcher\n* Decorator to register functions to handle HTTP methods\n* Optional JSON-schema input validation using same decorator\n\n### Support the development ❤️\n\nYou can support the development by:\n\n1. [Contributing code](https://github.com/trustpilot/python-lambdarest/blob/master/docs/CONTRIBUTING.md)\n2. [Buying the maintainer a coffee](https://buymeacoffee.com/sloev)\n3. [Buying some Lambdarest swag](https://www.redbubble.com/i/mug/Lambdarest-by-sloev/73793554.9Q0AD)\n\n    like this mug for example: \n\n    [![lambdarest mug](https://raw.githubusercontent.com/sloev/python-lambdarest/master/.github/lambdarest_mug.png)](https://www.redbubble.com/i/mug/Lambdarest-by-sloev/73793554.9Q0AD)\n\n### External articles / tutorials\n\n* [devgrok.com: Create a Private Microservice Using an Application Load Balancer](http://www.devgrok.com/2019/03/create-private-microservice-using.html)\n\n  Article about how to use **lambdarest** with **AWS Application Load Balancer**\n\n* [rockset.com: Building a Serverless Microservice Using Rockset and AWS Lambda](https://rockset.com/blog/building-a-serverless-microservice-using-rockset-and-aws-lambda/)\n\n  Article about how to set up **lambdarest** in AWS infrastructure\n\n**Other articles? add them [here](https://github.com/trustpilot/python-lambdarest/issues/55)**\n\n## Installation\n\nInstall the package from [PyPI](http://pypi.python.org/pypi/) using [pip](https://pip.pypa.io/):\n\n```bash\n$ pip install lambdarest\n```\n\n## Getting Started\n\nThis module helps you to handle different HTTP methods in your AWS Lambda.\n\n```python\nfrom lambdarest import lambda_handler\n\n@lambda_handler.handle("get")\ndef my_own_get(event):\n    return {"this": "will be json dumped"}\n\n##### TEST #####\n\ninput_event = {\n    "body": \'{}\',\n    "httpMethod": "GET",\n    "resource": "/"\n}\nresult = lambda_handler(event=input_event)\nassert result == {"body": \'{"this": "will be json dumped"}\', "statusCode": 200, "headers":{}}\n```\n\n## Documentation\n\nSee [docs](https://github.com/trustpilot/python-lambdarest/blob/master/docs/README.md) for **documentation and examples** covering amongst:\n\n* [Advanced usage example](https://github.com/trustpilot/python-lambdarest/blob/master/docs/README.md#advanced-usage)\n* [Query params](https://github.com/trustpilot/python-lambdarest/blob/master/docs/README.md#query-params)\n* [Headers and MultiValueHeaders](https://github.com/trustpilot/python-lambdarest/blob/master/docs/README.md#headers-and-multivalueheaders)\n* [Routing](https://github.com/trustpilot/python-lambdarest/blob/master/docs/README.md#routing)\n* [Authorization Scopes](https://github.com/trustpilot/python-lambdarest/blob/master/docs/README.md#authorization-scopes)\n* [Exception Handling](https://github.com/trustpilot/python-lambdarest/blob/master/docs/README.md#exception-handling)\n* [AWS Application Load Balancer](https://github.com/trustpilot/python-lambdarest/blob/master/docs/README.md#aws-application-load-balancer)\n* [CORS](https://github.com/trustpilot/python-lambdarest/blob/master/docs/README.md#cors)\n\n\n## Anormal unittest behaviour with `lambda_handler` singleton\n\nBecause of python unittests leaky test-cases it seems like you shall beware of [this issue](https://github.com/trustpilot/python-lambdarest/issues/16) when using the singleton `lambda_handler` in a multiple test-case scenario.\n\n## Tests\n\nThis package uses [Poetry](https://python-poetry.org/docs/) to install requirements and run tests.\n\nUse the following commands to install requirements and run test-suite:\n\n```bash\n$ poetry install\n$ poetry run task test\n```\n\nFor more info see [Contributing...](https://github.com/trustpilot/python-lambdarest/blob/master/docs/CONTRIBUTING.md)\n\n## Changelog\n\nSee [HISTORY.md](https://github.com/trustpilot/python-lambdarest/blob/master/docs/HISTORY.md)\n\n## Contributors\n\nThanks for contributing!\n\n[@sphaugh](https://github.com/sphaugh), [@amacks](https://github.com/amacks), [@jacksgt](https://github.com/jacksgt), [@mkreg](https://github.com/mkreg), [@aphexer](https://github.com/aphexer), [@nabrosimoff](https://github.com/nabrosimoff), [@elviejokike](https://github.com/elviejokike), [@eduardomourar](https://github.com/eduardomourar), [@devgrok](https://github.com/devgrok), [@AlbertoTrindade](https://github.com/AlbertoTrindade), [@paddie](https://github.com/paddie), [@svdgraaf](https://github.com/svdgraaf), [@simongarnier](https://github.com/simongarnier), [@martinbuberl](https://github.com/martinbuberl), [@adamelmore](https://github.com/adamelmore), [@sloev](https://github.com/sloev)\n\n[Wanna contribute?](https://github.com/trustpilot/python-lambdarest/blob/master/docs/CONTRIBUTING.md)\n\nAnd by the way, we have a [Code Of Friendlyhood!](https://github.com/trustpilot/python-lambdarest/blob/master/docs/CODE_OF_CONDUCT.md)\n',
    'author': 'Johannes Valbjørn',
    'author_email': 'johannes.valbjorn@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/trustpilot/python-lambdarest',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
